/** * Generates a database 'monoisotopic' from a monoisotopic mass and various options
 * @param {{smiles?:string,molecule?:string,idCode?:string}[]}    entries - Array of object containing a property to recreate the molecule
 * @param {import('openchemlib')} ocl - The OCL library
 * @param {object}    [options={}]
 * @param {function}  [options.onStep] - Callback to do after each step
 * @param {boolean}   [options.allowNeutral=true]
 * @param {string}    [options.ionizations=''] - string containing a comma separated list of modifications
 * @param {number}    [options.precision=100] - Allowed mass range based on precision
 * @param {boolean}   [options.groupResults=false] - Should we group the results if they have the same monoisotopic mass and experimental mass
 * @param {object}    [options.fragmentation={}]
 * @param {object}    [options.fragmentation.acyclic=false]
 * @param {object}    [options.fragmentation.cyclic=false]
 * @param {object}    [options.fragmentation.full=true]
 * @param {import('mf-matcher').MSEMFilterOptions}        [options.filter={}]
 * @returns {Promise}
 */
export function fromMolecules(entries: {
    smiles?: string;
    molecule?: string;
    idCode?: string;
}[], ocl: typeof import("openchemlib"), options?: {
    onStep?: Function | undefined;
    allowNeutral?: boolean | undefined;
    ionizations?: string | undefined;
    precision?: number | undefined;
    groupResults?: boolean | undefined;
    fragmentation?: {
        acyclic?: object;
        cyclic?: object;
        full?: object;
    } | undefined;
    filter?: import("mf-matcher").MSEMFilterOptions | undefined;
}): Promise<any>;
//# sourceMappingURL=fromMolecules.d.ts.map