export * from "./massShifts.js";
export * from "./util/fetchJSON.js";
/**
 * A class that deals with database of monoisotopic mass and molecular formula
 */
export class EMDB {
    databases: {};
    experimentalSpectrum: Spectrum | undefined;
    /**
     *
     * @param {*} data
     * @param {object} [options={}]
     * @param {boolean} [options.normed=true] Should we normed (sum Y to 1) the experimental spectrum ?
     * @param {number} [options.threshold=0.00025] Threshold used for peak picking
     */
    setExperimentalSpectrum(data: any, options?: {
        normed?: boolean | undefined;
        threshold?: number | undefined;
    }): Spectrum;
    /**
     * Add a new database using the KnapSack content
     * @param {*} options
     */
    loadKnapSack(options?: any): Promise<void>;
    /**
     * Add a new database of 12000 commercial products
     * @param {*} options
     */
    loadCommercials(options?: any): Promise<void>;
    get(databaseName: any): any;
    /**
     * Load the contaminants database from a google sheet document
     * @param {object} [options={}]
     * @param {string} [options.databaseName='contaminants']
     * @param {string} [options.forceReload=false]
     */
    loadContaminants(options?: {
        databaseName?: string | undefined;
        forceReload?: string | undefined;
    }): Promise<void>;
    /**
     * Load a google sheet containing MF information
     * @param {object} [options={}]
     * @param {string} [options.databaseName='sheet']
     * @param {string} [options.forceReload=false]
     */
    loadGoogleSheet(options?: {
        databaseName?: string | undefined;
        forceReload?: string | undefined;
    }): Promise<void>;
    loadTest(): Promise<void>;
    loadNeutralTest(options?: {}): Promise<void>;
    fromMonoisotopicMass(mass: any, options?: {}): Promise<any>;
    fromArray(sequence: any, options?: {}): Promise<any>;
    fromMolecules(entries: any, ocl: any, options?: {}): Promise<void>;
    fromRange(sequence: any, options?: {}): Promise<any>;
    fromPeptidicSequence(sequence: any, options?: {}): Promise<any>;
    /**
     *
     * @param {string} databaseName
     * @param {object} [options={}]
     * @param {number} [options.precision=100]
     * @param {string} [options.ionizations='']
     * @returns
     */
    appendFragmentsInfo(databaseName: string, options?: {
        precision?: number | undefined;
        ionizations?: string | undefined;
    }): Promise<any>;
    fromNucleicSequence(sequence: any, options?: {}): Promise<any>;
    listDatabases(): string[];
    getInfo(): {
        databases: {
            name: string;
            nbEntries: any;
        }[];
    };
    search(filter: any, options?: {}): {};
    searchMSEM(filter: any, options?: {}): {};
    searchSimilarity(options?: {}): Promise<any>;
}
import { Spectrum } from 'ms-spectrum';
//# sourceMappingURL=index.d.ts.map