/**
Search for an experimental monoisotopic mass and calculate the similarity
* @param {object}   [options={}]
* @param {array}    [options.databases] - an array containing the name of the databases so search, by default all
* @param {boolean}  [options.flatten] - should we return the array as a flat result
* @param {function} [options.onStep] - Callback to do after each step
* @param {string}   [options.ionizations=''] - Comma separated list of ionizations (to charge the molecule)
* @param {object}   [options.minSimilarity=0.5] - min similarity value

* @param {object}   [options.filter={}]
* @param {boolean}  [options.filter.forceIonization=false] - If true ignore existing ionizations
* @param {number}   [options.filter.msem] - Observed monoisotopic mass in mass spectrometer
* @param {number}   [options.filter.precision=1000] - The precision on the experimental mass
* @param {number}   [options.filter.minCharge=-Infinity] - Minimal charge
* @param {number}   [options.filter.maxCharge=+Infinity] - Maximal charge
* @param {boolean}  [options.filter.absoluteCharge=false] - If true, the charge is absolute (so between 0 and +Infinity by default)
* @param {object}   [options.filter.unsaturation={}]
* @param {number}   [options.filter.unsaturation.min=-Infinity] - Minimal unsaturation
* @param {number}   [options.filter.unsaturation.max=+Infinity] - Maximal unsaturation
* @param {boolean}  [options.filter.unsaturation.onlyInteger=false] - Integer unsaturation
* @param {boolean}  [options.filter.unsaturation.onlyNonInteger=false] - Non integer unsaturation
* @param {object}   [options.filter.atoms] - object of atom:{min, max}
* @param {object}   [options.filter.callback] - a function to filter the MF
* @param {object}   [options.similarity={}]
* @param {number}   [options.similarity.widthBottom]
* @param {number}   [options.similarity.widthTop]
* @param {object}   [options.similarity.widthFunction] - function called with mass that should return an object width containing top and bottom
* @param {object}   [options.similarity.zone={}]
* @param {number}   [options.similarity.zone.low=-0.5] - window shift based on observed monoisotopic mass
* @param {number}   [options.similarity.zone.high=2.5] - to value for the comparison window
* @param {boolean}  [options.similarity.zone.auto=false] - if true, low / high is determined based on the isotopic distribution and the threshold
* @param {string}   [options.similarity.common]
* @param {number}   [options.similarity.threshold=0.001] - when calculating similarity we only use the isotopic distribution with peaks over this relative threshold
* @param {number}   [options.similarity.limit] - We may define the maximum number of peaks to keep
* @returns {Promise}
*/
export function searchSimilarity(emdb: any, options?: {
    databases?: any[] | undefined;
    flatten?: boolean | undefined;
    onStep?: Function | undefined;
    ionizations?: string | undefined;
    minSimilarity?: object;
    filter?: {
        forceIonization?: boolean | undefined;
        msem?: number | undefined;
        precision?: number | undefined;
        minCharge?: number | undefined;
        maxCharge?: number | undefined;
        absoluteCharge?: boolean | undefined;
        unsaturation?: {
            min?: number | undefined;
            max?: number | undefined;
            onlyInteger?: boolean | undefined;
            onlyNonInteger?: boolean | undefined;
        } | undefined;
        atoms?: object;
        callback?: object;
    } | undefined;
    similarity?: {
        widthBottom?: number | undefined;
        widthTop?: number | undefined;
        widthFunction?: object;
        zone?: {
            low?: number | undefined;
            high?: number | undefined;
            auto?: boolean | undefined;
        } | undefined;
        common?: string | undefined;
        threshold?: number | undefined;
        limit?: number | undefined;
    } | undefined;
}): Promise<any>;
//# sourceMappingURL=searchSimilarity.d.ts.map